@@ -1,22 +1,8 @@
-/********************************************************************
-Copyright 2015  Martin Gräßlin <mgraesslin@kde.org>
+/*
+    SPDX-FileCopyrightText: 2015 Martin Gräßlin <mgraesslin@kde.org>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Lesser General Public
-License as published by the Free Software Foundation; either
-version 2.1 of the License, or (at your option) version 3, or any
-later version accepted by the membership of KDE e.V. (or its
-successor approved by the membership of KDE e.V.), which shall
-act as a proxy defined in Section 6 of version 3 of the license.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Lesser General Public License for more details.
-
-You should have received a copy of the GNU Lesser General Public
-License along with this library.  If not, see <http://www.gnu.org/licenses/>.
-*********************************************************************/
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 #ifndef WAYLAND_SERVER_PLASMA_WINDOW_MANAGEMENT_INTERFACE_H
 #define WAYLAND_SERVER_PLASMA_WINDOW_MANAGEMENT_INTERFACE_H
 
@@ -87,6 +73,13 @@ public:
      */
     PlasmaVirtualDesktopManagementInterface *plasmaVirtualDesktopManagementInterface() const;
 
+
+    /**
+     * Associate stacking order to this window management
+     * @since 5.70
+     */
+    void setStackingOrder(const QVector<quint32> &stackingOrder);
+
 Q_SIGNALS:
     void requestChangeShowingDesktop(ShowingDesktopState requestedState);
 
@@ -109,11 +102,12 @@ public:
     void setTitle(const QString &title);
     void setAppId(const QString &appId);
     void setPid(quint32 pid);
-#ifndef KWAYLANDSERVER_NO_DEPRECATED
+#if KWAYLANDSERVER_ENABLE_DEPRECATED_SINCE(5, 52)
     /**
-     * @deprecated use addPlasmaVirtualDesktop and removePlasmaVirtualDesktop
+     * @deprecated Since 5.52, use addPlasmaVirtualDesktop and removePlasmaVirtualDesktop
      */
-    void KWAYLANDSERVER_DEPRECATED setVirtualDesktop(quint32 desktop);
+    KWAYLANDSERVER_DEPRECATED_VERSION(5, 52, "Use PlasmaWindowManagementInterface::addPlasmaVirtualDesktop(const QString&) and PlasmaWindowManagementInterface::removePlasmaVirtualDesktop(const QString&)")
+    void setVirtualDesktop(quint32 desktop);
 #endif
     void setActive(bool set);
     void setMinimized(bool set);
@@ -129,12 +123,12 @@ public:
     void setFullscreenable(bool set);
     void setSkipTaskbar(bool skip);
     void setSkipSwitcher(bool skip);
+#if KWAYLANDSERVER_ENABLE_DEPRECATED_SINCE(5, 28)
     /**
      * @deprecated since 5.28 use setIcon
-     * @see setIcon
      **/
-#ifndef KWAYLANDSERVER_NO_DEPRECATED
-    void KWAYLANDSERVER_DEPRECATED setThemedIconName(const QString &iconName);
+    KWAYLANDSERVER_DEPRECATED_VERSION(5, 28, "Use PlasmaWindowManagementInterface::setIcon(const QIcon&)")
+    void setThemedIconName(const QString &iconName);
 #endif
     /**
      * @since 5.22
@@ -227,6 +221,20 @@ public:
      */
     QStringList plasmaVirtualDesktops() const;
 
+    /**
+     * Set the application menu D-BUS service name and object path for the window.
+     *
+     * @since 5.69
+     */
+    void setApplicationMenuPaths(const QString &serviceName, const QString &objectPath);
+
+    /**
+     * Return the window internal id
+     *
+     * @since 5.70
+     */
+    quint32 internalId() const;
+
 Q_SIGNALS:
     void closeRequested();
     /**
@@ -237,11 +245,12 @@ Q_SIGNALS:
      * @since 5.22
      */
     void resizeRequested();
-#ifndef KWAYLANDSERVER_NO_DEPRECATED
+#if KWAYLANDSERVER_ENABLE_DEPRECATED_SINCE(5, 52)
     /**
-     * @deprecated use enterPlasmaVirtualDesktopRequested and leavePlasmaVirtualDesktopRequested instead
+     * @deprecated Since 5.52, use enterPlasmaVirtualDesktopRequested and leavePlasmaVirtualDesktopRequested instead
      */
-    void KWAYLANDSERVER_DEPRECATED virtualDesktopRequested(quint32 desktop);
+    KWAYLANDSERVER_DEPRECATED_VERSION(5, 52, "Use PlasmaWindowManagementInterface::enterPlasmaVirtualDesktopRequested(const QString&) and PlasmaWindowManagementInterface::leavePlasmaVirtualDesktopRequested(const QString&)")
+    void virtualDesktopRequested(quint32 desktop);
 #endif
     void activeRequested(bool set);
     void minimizedRequested(bool set);
